  # Helpers para auxiliar o uso do Twitter Bootstrap em Rails Apps
  #
  # Author::    Luiz Eduardo de Oliveira Fomseca - Agência Orangeweb  (mailto:apps@orangeweb.com.br)
  # Copyright:: Copyright (c) 2011 Agência Orangeweb, MEI
  # License::   MIT

require 'tw_bootstrap_helper/railtie.rb'

# GEM tw_bootstrap_helper 
module TwBootStrapHelper  

# Extende os Helpers da Aplicação
module ViewHelper
  
  def bootstrap_link_to title, path, type, options={}
  
    options[:class] = "" unless options.has_key?(:class) 
    options[:class].insert(0, " btn " + type.to_s)
	
	if options.has_key?(:small) then
	   if options[:small] == true then
		options[:class].insert(-1, " small ")
	   end	
		options.delete(:small)
	end
	
	options[:class].to_s.strip!
    link_to title, path, options
	
  end
  
  # Default Options from Links with Bootstraper
  
  def default_link_to title, path, options={}
    bootstrap_link_to title, path, :default, options
  end
    
  
  def primary_link_to title, path, options={}
    bootstrap_link_to title, path, :primary, options
  end  
  
  
  def info_link_to title, path, options={}
    bootstrap_link_to title, path, :info, options
  end  
  
  
  def success_link_to title, path, options={}
    bootstrap_link_to title, path, :success, options
  end  
  
  
  def danger_link_to title, path, options={}
    bootstrap_link_to title, path, :danger, options
  end  
    
  # Commom Alias from Links
  
  def pill_link_to title, path, options={}
    link_to title, path, options
  end    
  
  def new_link_to title, path, options={}
    success_link_to title, path, options
  end  
  
  def cancel_link_to title, path, options={}
    default_link_to title, path, options
  end
  
  def edit_link_to title, path, options={} 
    info_link_to title, path, options
  end  
  
  def delete_link_to title, path, options={}
    options[:confirm] = 'Tem certeza que deseja apagar este item?'
	options[:method] = :delete
    danger_link_to title, path, options
  end   
  
  # Show a Pill Toolbar
  def pill(&block)
    content = capture(&block)
    content_tag(:div, content_tag(:ul, content, :class => "pills"))
  end
  
  # Show a Pill Toolbar Item
  def pill_item(&block)
    content = capture(&block)
    content_tag(:li, content)
  end   
  
  
  def bootstrap_label title, type, options={}
    options[:class] = "" unless options.has_key?(:class) 
    options[:class].insert(0, " label " + type.to_s)
    raw content_tag :span, " #{title} ", options
  end 
  
  def label_default title, options={}
	bootstrap_label title, :default, options={}
  end
  
  def label_success title, options={}
	bootstrap_label title, :success, options={}
  end  
  
  def label_warning title, options={}
	bootstrap_label title, :warning, options={}
  end    
  
  def label_important title, options={}
	bootstrap_label title, :important, options={}
  end   
  
  def label_notice title, options={}
	bootstrap_label title, :notice, options={}
  end   
  
  # Commom Alias from Labels

  def label_new title="Novo"
	label_success title
  end
  
  def label_error title="Erro"
	label_important title
  end  
  
  def label_incomplete title="Incompleto"
	label_warning title
  end  

  def label_details title="+ Detalhes"
	label_notice title
  end 
  
  def label_back title="<< Voltar"
	label_default title
  end   
  
  
  # Grids
  
  # Bootstrap Row Grid
  def grid_row(&block)
    content = capture(&block)
    raw content_tag(:div, content, :class => "grid row") 
  end    
  
  
  # Bootstrap Col Grid
  def grid_col(cols, center=true,&block)
    content = capture(&block)
    cl = "span#{cols}"    
    content_tag(:div, content, :class => cl)
  end   
  
  
   # Bootstrap Row Grid
  def nav_icon(title, link)
    raw content_tag(:div, link + content_tag(:span, title), :class => "nav-icon-item  corner h-margin v-margin") 
  end   
  
  
  #============ HTML HELPERS ================
  
  def table(opts={}, &block)
    content = capture(&block)
    
    opts[:class] = "zebra-striped"
    
    content_tag(:table, content, opts)
  end  
  
  
  def table_head(&block)
    content = capture(&block)
    content_tag(:thead, content_tag(:tr, content))
  end  
  
  
  def table_th_block(options={}, &block)
    content = capture(&block)
    content_tag(:th, content)
  end  
  
  def table_th(value="", options={})
    content_tag(:th, value)
  end   
  
  
  def table_body(&block)
    content = capture(&block)
    content_tag(:tbody, content)
  end
    
  
  def table_tr(&block)
    content = capture(&block)
    content_tag(:tr, content)
  end 
  
  def table_td_block(options={}, &block)
    content = capture(&block)
    content_tag(:td, content, options)
  end
  
  def table_td(value="", options={})
    content_tag(:td, value, options)
  end  
  
  def lorem_ipsum
    <<-eos 
      Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris fermentum tempor arcu in mollis. 
      Aliquam erat volutpat. Sed malesuada lacinia nibh, eget posuere turpis accumsan vitae. Aliquam lacus massa, pellentesque auctor volutpat eu, luctus ac enim.
      Nullam venenatis tellus nec tortor dictum rutrum. Proin sed magna eu mauris posuere vulputate vel quis nunc. Donec at elit sapien, vitae mattis arcu. Maecenas sollicitudin auctor volutpat. Vivamus tincidunt interdum placerat.
      In mattis, metus vel pellentesque accumsan, neque nisi ornare lectus, et interdum lectus ipsum sed augue. Nullam sollicitudin placerat enim a lobortis.
      Curabitur id lorem turpis, sit amet euismod elit.
    eos
  end 
  
end  
  
end